// Basic setup for 8-ball pool game in React using HTML Canvas
import React, { useRef, useEffect, useState } from 'react';
import axios from 'axios';

const TABLE_WIDTH = 800;
const TABLE_HEIGHT = 400;
const BALL_RADIUS = 10;

const generateBalls = () => {
  const balls = [];
  const offsetX = 500;
  const offsetY = 200;

  // Cue ball
  balls.push({ id: 'cue', x: 100, y: 200, vx: 0, vy: 0, color: 'white' });

  // Triangle of balls
  let count = 0;
  for (let row = 0; row < 5; row++) {
    for (let col = 0; col <= row; col++) {
      balls.push({
        id: `ball${count++}`,
        x: offsetX + row * BALL_RADIUS * 2,
        y: offsetY - row * BALL_RADIUS + col * BALL_RADIUS * 2,
        vx: 0,
        vy: 0,
        color: getBallColor(count),
      });
    }
  }
  return balls;
};

const getBallColor = (index) => {
  const colors = ['yellow', 'blue', 'red', 'purple', 'orange', 'green', 'maroon', 'black'];
  return colors[index % colors.length];
};

export default function PoolGame() {
  const canvasRef = useRef(null);
  const [balls, setBalls] = useState(generateBalls());
  const [activePlayers, setActivePlayers] = useState(0);
  const [phoneNumber, setPhoneNumber] = useState('');
  const [amount, setAmount] = useState('');

  useEffect(() => {
    const canvas = canvasRef.current;
    const ctx = canvas.getContext('2d');
    let animationFrameId;

    const drawTable = () => {
      ctx.fillStyle = '#35654d';
      ctx.fillRect(0, 0, TABLE_WIDTH, TABLE_HEIGHT);
    };

    const drawBalls = () => {
      balls.forEach(ball => {
        ctx.beginPath();
        ctx.arc(ball.x, ball.y, BALL_RADIUS, 0, Math.PI * 2);
        ctx.fillStyle = ball.color;
        ctx.fill();
        ctx.closePath();
      });
    };

    const render = () => {
      drawTable();
      drawBalls();
      animationFrameId = window.requestAnimationFrame(render);
    };

    render();
    return () => cancelAnimationFrame(animationFrameId);
  }, [balls]);

  useEffect(() => {
    const fetchActivePlayers = async () => {
      try {
        const res = await axios.get('/api/active-players');
        setActivePlayers(res.data.count);
      } catch (err) {
        console.error('Error fetching active players:', err);
      }
    };
    fetchActivePlayers();
    const interval = setInterval(fetchActivePlayers, 10000);
    return () => clearInterval(interval);
  }, []);

  const handleDeposit = async () => {
    try {
      await axios.post('/api/mpesa/deposit', { phone: phoneNumber, amount });
      alert('Deposit initiated via M-PESA');
    } catch (err) {
      console.error(err);
      alert('Deposit failed');
    }
  };

  const handleWithdraw = async () => {
    try {
      await axios.post('/api/mpesa/withdraw', { phone: phoneNumber, amount });
      alert('Withdrawal request sent');
    } catch (err) {
      console.error(err);
      alert('Withdrawal failed');
    }
  };

  return (
    <div className="flex flex-col items-center p-4 space-y-4">
      <canvas
        ref={canvasRef}
        width={TABLE_WIDTH}
        height={TABLE_HEIGHT}
        className="rounded-xl shadow-lg border border-gray-500"
      />

      <div className="text-white text-lg">Active Players: {activePlayers}</div>

      <div className="flex flex-col items-center space-y-2">
        <input
          type="text"
          placeholder="Phone Number"
          value={phoneNumber}
          onChange={(e) => setPhoneNumber(e.target.value)}
          className="px-2 py-1 border rounded"
        />
        <input
          type="text"
          placeholder="Amount"
          value={amount}
          onChange={(e) => setAmount(e.target.value)}
          className="px-2 py-1 border rounded"
        />
        <div className="flex space-x-2">
          <button
            onClick={handleDeposit}
            className="bg-green-600 text-white px-4 py-2 rounded"
          >
            Deposit (M-PESA)
          </button>
          <button
            onClick={handleWithdraw}
            className="bg-blue-600 text-white px-4 py-2 rounded"
          >
            Withdraw
          </button>
        </div>
      </div>
    </div>
  );
}
